\name{tolEstimate}
\alias{tolEstimate}
\alias{print..TolEstimate}
\alias{plot..TolEstimate}
\alias{coef..TolEstimate}
\alias{residuals..TolEstimate}
\alias{fitted..TolEstimate}
\alias{vcov..TolEstimate}
\title{TOL Estimate}
\description{
Estimates a linear model with an ARIMA structured noise, i.e. an ARIMA model with external regressors.
Note than it is not an ARIMAX model as usual, since AR block affects the regressed variable (output) as the regressors (inputs).
}
\usage{
tolEstimate(output, inputs, ..., coeffs = list(), dif = 1, AR = list(), MA = list(), period = 1, power = 1, shift = 0)
\method{print}{.TolEstimate}(x, \dots)
\method{plot}{.TolEstimate}(x, \dots)
\method{coef}{.TolEstimate}(object, \dots)
\method{residuals}{.TolEstimate}(object, \dots)
\method{fitted}{.TolEstimate}(object, \dots)
\method{vcov}{.TolEstimate}(object, \dots)
}
\arguments{
  \item{output}{
  the Serie object to be estimated.
}
  \item{inputs}{
  a list of Serie objects than are used as linear regressors.
}
  \item{\dots}{
  further arguments. For example, use \code{legend.names=list()}  to show default legend when plotting. See method \code{\link{plot.Serie}} for other arguments.
}
  \item{coeffs}{
  a list with the initial coefficients or Polyn objects for each input (or regressor).
}
  \item{dif}{
  a Polyn object with the difference to be applied.
}
  \item{AR}{
  a list of Polyn objects with the initial AR polynomials, one for each ARIMA block.
}
  \item{MA}{
  a list of Polyn objects with the initial MA polynomials, one for each ARIMA block.
}
  \item{period}{
  the periodicity of the seasonal part of the ARIMA structure. This argument has only a documentary purpose. Its use became obsolete with the introduction of multiple seasonalities.
}
  \item{power, shift}{
  parameters of the power transformation: \code{T(x) = (x+shift)^power} or \code{T(x) = Log(x+shift)} when \code{power} is zero.
}
  \item{x, object}{
  an estimation.
}
}
\value{
The function \code{tolEstimate} returns an Estimation object (class .TolEstimation)
that can be used with the generalized methods: \code{\link{print}}, \code{\link{coef}}, \code{\link{residuals}}, \code{\link{fitted}}  and \code{\link{vcov}}.
}
\seealso{
See also the forecasting function \code{\link{tolCalcForecasting}}.

See reference documentation of \link{Serie} objects and the method \code{\link{plot.Serie}}.
}
\examples{
# ARIMA model estimation for the USAccDeaths time-series
est <- tolEstimate(as.Serie(USAccDeaths),
  dif=(1-B)*(1-B^12), MA=list(1-0.1*B, 1-0.1*B^12))
print(est)
plot(est)
acf(residuals(est))
}
\keyword{Estimate}
